All of lore.kernel.org
 help / color / mirror / Atom feed
From: Stas Sergeev <stssppnn@yahoo.com>
To: linux-msdos@vger.kernel.org
Subject: Re: IPX without suidroot
Date: Thu, 01 Aug 2002 18:02:58 +0400	[thread overview]
Message-ID: <3D493F92.8000801@yahoo.com> (raw)

[-- Attachment #1: Type: text/plain, Size: 845 bytes --]

Hello.

Reinhard Karcher wrote:
>> Only question I have: "Can I use IPX while being simple user
>> without any sudo or suidroot?"
>  As far as I know, it is not possible. Dosemu has to create sockets
>  of the IPX-type, and thagt can't be done without rootpriviledges.
I *think* (without too much knowledge
of an IPX networking) that this is
possible.
I have traced the IPXOpenSocket()
and the only place which fails without
root is setting SO_DEBUG opt to
socket which is used only for
debugging and must not fail, so it's
a bug.
For everything else root doesn't
seem to be required.
I started doom's ipxsetup and it
doesn't complain, log indicates
that packets are floating OK.
So I think IPX must work without
root.
And if not, Grigory or Reinhard,
please apply the attached patch
and produce a -D9+n log and also
cat /proc/net/ipx_interface

[-- Attachment #2: ipx_root.diff --]
[-- Type: text/plain, Size: 802 bytes --]

--- src/dosext/net/net/ipx.c	Fri Jul 19 02:04:37 2002
+++ src/dosext/net/net/ipx.c	Thu Aug  1 17:30:44 2002
@@ -443,17 +443,14 @@
   }
 
   opt = 1;
-  /* turn on socket debugging */
-  if (debug_level('n')) {
+  /* turn on socket debugging - requires root! */
+  if (debug_level('n') && can_do_root_stuff) {
     enter_priv_on();
-    if (setsockopt(sock, SOL_SOCKET, SO_DEBUG, &opt, sizeof(opt)) == -1) {
-      leave_priv_setting();
+    if (setsockopt(sock, SOL_SOCKET, SO_DEBUG, &opt, sizeof(opt)) == -1)
       n_printf("IPX: could not set socket option for debugging: %s.\n", strerror(errno));
-      /* I can't think of anything else to return */
-      return (RCODE_SOCKET_TABLE_FULL);
-    }
     leave_priv_setting();
   }
+
   opt = 1;
   /* Permit broadcast output */
   enter_priv_on();

             reply	other threads:[~2002-08-01 14:02 UTC|newest]

Thread overview: 11+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2002-08-01 14:02 Stas Sergeev [this message]
2002-08-02 10:52 ` IPX without suidroot Grigory Batalov
  -- strict thread matches above, loose matches on Subject: below --
2002-08-02 17:19 Stas Sergeev
2002-08-02 21:43 ` Grigory Batalov
2002-08-05  5:47 ` Grigory Batalov
2002-08-02 14:37 Stas Sergeev
2002-08-02 15:52 ` Grigory Batalov
2002-08-02 12:38 Stas Sergeev
2002-08-02 13:47 ` Grigory Batalov
2002-08-01 10:36 Grigory Batalov
2002-08-01 11:58 ` Reinhard Karcher

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=3D493F92.8000801@yahoo.com \
    --to=stssppnn@yahoo.com \
    --cc=linux-msdos@vger.kernel.org \
    --cc=stas.orel@mailcity.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.